@@ -1,5 +1,5 @@
-import torch
-import torch_xla.core.xla_model as xm
+#import torch
+#import torch_xla.core.xla_model as xm
 from keytotext import trainer, make_dataset
 
 train_df = make_dataset('common_gen', split='train')
